==========================================
2016-07-05 Stewardship Working Group (SWG)
==========================================

Over the past several years, OpenStack has experienced rapid growth
and this has placed some strains on the scalability of several
governance processes. The Technical Committee believes that there are
opportunities to improve our leadership and communication tools and
practices. To that end, a training session for TC members was planned
for June 2016.

Several members of the TC, and some other community members attended
this training, which was based on best practices and learnings of the
Zingerman's Community of Businesses. The participants agreed that some
of the challenges that the TC faces could be improved by adopting and
adapting some of the concepts discussed in the training.

Rather than trying to have the entire TC work on this as a body, we
would benefit from establishing a small group to review the
leadership, communication, and decision making processes of the TC and
OpenStack projects as a whole, and propose a set of improvements based
on the training but tailored for our needs. We propose calling this
group the "Stewardship Working Group" (SWG). The term "stewardship"
came up in the training program [1]_ , and fits the purpose of this new
working group and the "Servant Leadership" model used within our
community, defined by Peter Block in the book by the same name [2]_ :

     "Stewardship is defined in this book as the choice to preside
     over the orderly distribution of power. This means giving people
     at the bottom and the boundaries of the organization choice over
     how to serve a customer, a citizen, a community. It is the
     willingness to be accountable for the well-being of the larger
     organization by operating in service, rather than in control, of
     those around us. Stated simply, it is accountability without
     control or compliance."[3]_

The concept of stewardship is particularly relevant in the OpenStack
community where leadership does not usually include explicit
organizational authority, and has to be accomplished through agreement
and consensus building.

The SWG will be responsible for producing actionable recommendations
and improvements that the TC can then consider for adoption and roll
out to the OpenStack community. This group was started by a group of
interested participants of the training in Ann Arbor. Anyone
interested in leadership, stewardship, and OpenStack is welcome to
join the working group. Final decisions about any changes proposed by
the SWG will be made by the TC.

It would be good if the group could provide the TC with a draft set of
recommendations by August 15, 2016, and definitely have a concrete set of
recommendations to the TC in time for the summit in Barcelona.

References
==========

.. [1] http://www.zingtrain.com/content/stewardship-building-power-without-using-authority

.. [2] https://www.amazon.com/Stewardship-Choosing-Service-Over-Self-Interest/dp/160994822X

.. [3] https://www.bkconnection.com/static/Stewardship_2nd_EXCERPT.pdf

